@@ -31,6 +31,10 @@ class AirtelMoney(object):
 
     def paymentRequest(self, data):
         """ main function for payment requests """
+        LOGS.logger.info(
+            "[AirtelMoney] Incoming request: {}"
+            .format(data)
+        )
         try:
             jresponse = self.sendPaymentRequest(data)
             if jresponse:
@@ -280,7 +284,8 @@ class AirtelMoney(object):
         """Updates a given transaction's status inside Redis."""
         order_id = transaction['order_id']
         LOGS.logger.info(
-            "[AirtelMoney]{}\n\n".format(order_id)
+            "[AirtelMoney][{}] Redis updated: key={}, value={}"
+            .format(order_id, self.redis_key, transaction)
         )
         REDIS_DB.hmset(self.redis_key, transaction)
 
