@@ -28,7 +28,7 @@ def airtelCheckTransactionStatus():
         "{}\n\n".format(data)
     )
     airtelmoney = AirtelMoney(data)
-    response = airtelmoney.checkTransactionStatus(data['operation_id'])
+    response = airtelmoney.checkTransactionStatus()
     return jsonify(response)
 
 
@@ -57,4 +57,16 @@ def airtelCheckRedis():
     response = airtelmoney.checkTransactionStatusRedis(data["operation_id"])
     return jsonify(response)
 
+
+@api.route("/airtelmoney/getStatus", methods=["GET"])
+def airtelGetStatus():
+    """
+    Fetches the transaction status directly to Airtel.
+    Only used by support N1.
+    """
+    args = request.get_json()
+    airtelmoney = AirtelMoney(args)
+    response = airtelmoney.getStatus(args["operation_id"])
+    return jsonify(response)
+
 # EOF
