@@ -271,7 +271,7 @@ class IzyTV(object):
         for data in self.sort_data():
             date = data['TransactionDate']
             day, hour = date.split(' ')
-            if (day in hier) and (data["status"] == "Transaction validée") and (data["info"] == "Activation reussie"):
+            if day in hier:
                 try:
                     write_transaction_to_db(**data)
                 except Exception as e:
