@@ -15,6 +15,10 @@ class Mvola(object):
         self.url = MVOLA["url"]
 
     def paymentRequest(self, data):
+        LOGS.logger.info(
+            "[MVola] Incoming request: {}"
+            .format(data)
+        )
         params = {
             "Login_WS": MVOLA["login"],
             "Password_WS": MVOLA["pwd"],
@@ -26,14 +30,19 @@ class Mvola(object):
             "ShopShippingAddress": data["other"]
         }
         try:
-            LOGS.logger.info("Payment request, let's go")
             mvola_client = Client(self.url)
             response = mvola_client.service.WS_MPGw_PaymentRequest(
                 MVOLA["apiversion"],
                 params
             )
+            LOGS.logger.info(
+                "[MVola][{}] Payment request response: {}"
+                .format(data["operation_id"], response.text)
+            )
         except Exception as e:
-            LOGS.logger.info(e)
+            LOGS.logger.error(
+                "[MVola][{}] {}".format(data["operation_id"], str(e))
+            )
             response = {
                 "code": "{}-404".format(SERVICE_CODE),
                 "response": {},
@@ -63,6 +72,10 @@ class Mvola(object):
                 data["status"] = "En attente de paiement"
                 data["info"] = "Activation en attente"
                 redis_key = "request:payment:{}".format(response["MPGw_TokenID"])
+                LOGS.logger.info(
+                    "[MVola][{}] Redis updated: key={}, value={}"
+                    .format(data["operation_id"], redis_key, data)
+                )
                 REDIS_DB.hmset(redis_key, data)
                 # REDIS_DB.expire(redis_key, 86400)
                 response = {
@@ -93,7 +106,9 @@ class Mvola(object):
                 params
             )
         except Exception as e:
-            LOGS.logger.info(e)
+            LOGS.logger.error(
+                "[MVola][{}] {}".format(tokenId, str(e))
+            )
             code = "{}-404".format(SERVICE_CODE)
             ResponseCode = None
             MvolaTransactionStatus = None
