@@ -31,6 +31,10 @@ class OrangeMoney(object):
             return None
 
     def paymentRequest(self, data):
+        LOGS.logger.info(
+            "[OrangeMoney] Incoming request: {}"
+            .format(data)
+        )
         token = self.requestToken()
         if token:
             or_data = {
